==> walletconnect_flutter_v2-2.1.5.tar.gz: example/dapp/lib/utils/string_constants.dart <==
class StringConstants {
  // General
  static const String cancel = 'Cancel';
  static const String close = 'Close';
  static const String ok = 'OK';
  static const String delete = 'Delete';

  // Main Page
  static const String appTitle = 'Wallet Connect v2 Flutter dApp Demo';
  static const String connectPageTitle = 'Connect';
  static const String pairingsPageTitle = 'Pairings';
  static const String sessionsPageTitle = 'Sessions';
  static const String authPageTitle = 'Auth';
  static const String settingsPageTitle = 'Settings';
  static const String receivedPing = 'Received Ping';
  static const String receivedEvent = 'Received Event';

  // Connect Page
  static const String selectChains = 'Select chains:';
  static const String testnetsOnly = 'Testnets only?';
  static const String scanQrCode = 'Scan QR Code';
  static const String copiedToClipboard = 'Copied to clipboard';
  static const String connect = 'Connect';
  static const String connectionEstablished = 'Session established';
  static const String connectionFailed = 'Session setup failed';
  static const String authSucceeded = 'Authentication Successful';
  static const String authFailed = 'Authentication Failed';

  // Pairings Page
  static const String pairings = 'Pairings';
  static const String deletePairing = 'Delete Pairing?';

  // Sessions Page
  static const String sessions = 'Sessions';
  static const String noSessionSelected = 'No session selected';
  static const String sessionTopic = 'Session Topic: ';
  static const String methods = 'Methods';
  static const String events = 'Events';
}

==> walletconnect_flutter_v2-2.2.3.tar.gz: example/dapp/lib/utils/string_constants.dart <==
class StringConstants {
  // General
  static const String cancel = 'Cancel';
  static const String close = 'Close';
  static const String ok = 'OK';
  static const String delete = 'Delete';

  // Main Page
  static const String appTitle = 'WalletConnect v2\nFlutter dApp Demo';
  static const String connectPageTitle = 'Connect';
  static const String pairingsPageTitle = 'Pairings';
  static const String sessionsPageTitle = 'Sessions';
  static const String authPageTitle = 'Auth';
  static const String settingsPageTitle = 'Settings';
  static const String receivedPing = 'Received Ping';
  static const String receivedEvent = 'Received Event';

  // Connect Page
  static const String selectChains = 'Select chains:';
  static const String testnetsOnly = 'Testnets only?';
  static const String scanQrCode = 'Scan QR Code';
  static const String copiedToClipboard = 'Copied to clipboard';
  static const String connect = 'Connect';
  static const String connectionEstablished = 'Session established';
  static const String connectionFailed = 'Session setup failed';
  static const String connectionRejected = 'Connection rejected by user';
  static const String authSucceeded = 'Authentication Successful';
  static const String authFailed = 'Authentication Failed';

  // Pairings Page
  static const String pairings = 'Pairings';
  static const String deletePairing = 'Delete Pairing?';

  // Sessions Page
  static const String sessions = 'Sessions';
  static const String noSessionSelected = 'No session selected';
  static const String sessionTopic = 'Session Topic: ';
  static const String methods = 'Methods';
  static const String events = 'Events';
}
